/*
 * Copyright 2020 IQTIG – Institut für Qualitätssicherung und Transparenz im Gesundheitswesen.
 * Dieser Code ist urheberrechtlich geschützt (Copyright).
 * Das Urheberrecht liegt, soweit nicht ausdrücklich anders gekennzeichnet, beim IQTIG.
 * Wer gegen das Urheberrecht verstößt, macht sich gem. § 106 ff Urhebergesetz strafbar.
 * Er wird zudem kostenpflichtig abgemahnt und muss Schadensersatz leisten.
 */
package org.iqtig.od.psp.impl.examples;

import java.nio.file.Files;
import java.nio.file.Path;
import java.security.cert.X509Certificate;
import org.iqtig.od.psp.api.KeyManagement;
import org.iqtig.od.psp.api.Pseudonymisator;
import org.iqtig.od.psp.api.beans.CertificateIdentity;
import org.iqtig.od.psp.api.enums.PseudonymisationProcedure;
import org.iqtig.od.psp.api.exception.PspApiException;
import org.iqtig.od.psp.impl.APIBuilder;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * Beispiel einer Pseudonymisierung mit einem öffentlichen Schlüssel
 * welcher aus einer Zertifikats-Datei geladen wird.
 */
class PseudonymisationExampleTest {

	private static final String CERTIFICATE_FILE_NAME = "target/test-classes/test/impl/examples/LQS$$BB20200101.cer";

	private Pseudonymisator pseudonymisator;

	@BeforeEach
	void beforeEach() throws PspApiException {
		final Path certificateFilePath = Path.of(CERTIFICATE_FILE_NAME);
		final APIBuilder builder = new APIBuilder();
		final KeyManagement keyManagement = builder.getKeyManagement();

		final X509Certificate x509Certificate = Assertions
			.assertDoesNotThrow(() -> keyManagement.readCertificateFromPem(Files.newInputStream(certificateFilePath)));
		final CertificateIdentity certificateIdentity = CertificateIdentity.createValidatedCertificateIdentity(certificateFilePath);

		this.pseudonymisator = builder.getPseudonymisator(certificateIdentity, x509Certificate.getPublicKey());
	}

	@Test
	void testForIkBs() {
		Assertions.assertDoesNotThrow(() -> pseudonymisator.pseudonymiseIKBS("261111111", PseudonymisationProcedure.CHE));
	}

	@Test
	void testForStoId() {
		Assertions.assertDoesNotThrow(() -> pseudonymisator.pseudonymiseStoId("771111", PseudonymisationProcedure.CHE));
	}
}
